import os

AWS_ACCESS_KEY = os.getenv("AWS_ACCESS_KEY")
AWS_SECRET_KEY = os.getenv("AWS_SECRET_KEY")
S3_BUCKET = os.getenv("S3_BUCKET")

MLFLOW_TRACKING_URI = os.getenv("MLFLOW_SERVER_TRACKING_URI", "")
print(MLFLOW_TRACKING_URI)



import sys
from settings import MLFLOW_SERVER_TRACKING_URI


# Data Manipulation
import numpy as np
import pandas as pd

# Preprocessing
from sklearn.model_selection import train_test_split
from sklearn import model_selection, tree, preprocessing, metrics, linear_model
from sklearn.ensemble import GradientBoostingClassifier

import mlflow
import mlflow.sklearn



mlflow.set_tracking_uri(MLFLOW_SERVER_TRACKING_URI)
EXPERIMENT_ID = mlflow.set_experiment('*project_name*')

def train_model():
    with mlflow.start_run(experiment_id=EXPERIMENT_ID):

        # INSERT YOUR CODE HERE #


        #LOG PARAM METRICS & ARTIFACTS EXAMPLES
        mlflow.log_param("learning rate", learning_rate)
        mlflow.log_param("n_estimators", estimators)
        mlflow.log_param("loss", loss)
        mlflow.log_metric("accuracy", acc)
        mlflow.log_metric("accuracy cross-validated", acc_cv)

        mlflow.sklearn.log_model(model, "model")



import os
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

def package_files(directory):
    paths = []
    for (path, _, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

files = package_files('otto/files')
setuptools.setup(
    name="otto-ml",
    version="0.1.12",
    author="Carlos Rodrigo",
    author_email="hi@carlosrodrigo.me",
    description="Otto is a simple Boilerplate for Machine Learning projects integrated with MLflow tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/carlos-rodrigo/otto-ml",
    packages=setuptools.find_packages(),
    package_data={"otto": files},
    install_requires=[
        'click>=7.0',
        'numpy',
        'pandas',
        'mlflow'
    ],
    extras_require={
        'extras':[
            "scikit-learn; python_version >= '3.5'",
            # scikit-learn 0.20 is the last version to support Python 2.x  & Python 3.4.
            "scikit-learn==0.20; python_version < '3.5'",
            'boto3>=1.7.12',
        ],
    },
    entry_points='''
        [console_scripts]
        otto=otto.cli:init
    ''',    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
)
